==> open-cluster-management-operator-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/MultiClusterHubListBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MultiClusterHubListBuilder extends MultiClusterHubListFluentImpl<MultiClusterHubListBuilder> implements VisitableBuilder<MultiClusterHubList,MultiClusterHubListBuilder>{
  public MultiClusterHubListBuilder() {
    this(false);
  }
  public MultiClusterHubListBuilder(Boolean validationEnabled) {
    this(new MultiClusterHubList(), validationEnabled);
  }
  public MultiClusterHubListBuilder(MultiClusterHubListFluent<?> fluent) {
    this(fluent, false);
  }
  public MultiClusterHubListBuilder(MultiClusterHubListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MultiClusterHubList(), validationEnabled);
  }
  public MultiClusterHubListBuilder(MultiClusterHubListFluent<?> fluent,MultiClusterHubList instance) {
    this(fluent, instance, false);
  }
  public MultiClusterHubListBuilder(MultiClusterHubListFluent<?> fluent,MultiClusterHubList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MultiClusterHubListBuilder(MultiClusterHubList instance) {
    this(instance,false);
  }
  public MultiClusterHubListBuilder(MultiClusterHubList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  MultiClusterHubListFluent<?> fluent;
  Boolean validationEnabled;
  public MultiClusterHubList build() {
    MultiClusterHubList buildable = new MultiClusterHubList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}

==> open-cluster-management-operator-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/MultiClusterHubListBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MultiClusterHubListBuilder extends MultiClusterHubListFluent<MultiClusterHubListBuilder> implements VisitableBuilder<MultiClusterHubList,MultiClusterHubListBuilder>{
  public MultiClusterHubListBuilder() {
    this(false);
  }
  public MultiClusterHubListBuilder(Boolean validationEnabled) {
    this(new MultiClusterHubList(), validationEnabled);
  }
  public MultiClusterHubListBuilder(MultiClusterHubListFluent<?> fluent) {
    this(fluent, false);
  }
  public MultiClusterHubListBuilder(MultiClusterHubListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MultiClusterHubList(), validationEnabled);
  }
  public MultiClusterHubListBuilder(MultiClusterHubListFluent<?> fluent,MultiClusterHubList instance) {
    this(fluent, instance, false);
  }
  public MultiClusterHubListBuilder(MultiClusterHubListFluent<?> fluent,MultiClusterHubList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new MultiClusterHubList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MultiClusterHubListBuilder(MultiClusterHubList instance) {
    this(instance,false);
  }
  public MultiClusterHubListBuilder(MultiClusterHubList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new MultiClusterHubList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
    }
    this.validationEnabled = validationEnabled; 
  }
  MultiClusterHubListFluent<?> fluent;
  Boolean validationEnabled;
  public MultiClusterHubList build() {
    MultiClusterHubList buildable = new MultiClusterHubList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  
}
